# (c) Copyright 2009-2013. CodeWeavers, Inc.

import os

import gobject
import gtk
import gtk.glade
gtk.gdk.threads_init()

import cxutils

import cxguitools


class WaitDialogController(object):

    def __init__(self, options, args):
        try:
            glade_path = os.environ["CX_GLADEPATH"]
        except KeyError:
            glade_path = os.path.join(cxutils.CX_ROOT, "lib", "python", "glade")

        self.glade_file = os.path.join(glade_path, "waitdlg.ui")
        if not gtk.glade.textdomain() == "crossover":
            locale_path = os.path.join(cxutils.CX_ROOT, "share", "locale")
            gtk.glade.bindtextdomain("crossover", locale_path)
            gtk.glade.textdomain("crossover")
        self.xml = gtk.Builder()
        self.xml.add_from_file(self.glade_file)
        self.xml.connect_signals(self)

        # We have a c-style string format, and need to convert it.
        message_format = cxutils.cxgettext(args[0])
        try:
            message = message_format % tuple(args[1:])
        except TypeError:
            message = message_format

        window = self.xml.get_object("WaitDlg")
        window.set_property('focus-on-map', not options.nofocus)

        # Set up title
        if options.title:
            window.set_title(cxutils.cxgettext(options.title))

        # Set up image
        if options.image:
            image = self.xml.get_object("WaitImage")
            if '/' in options.image:
                image.set_from_file(options.image)
            else:
                image.set_from_pixbuf(cxguitools.get_std_icon(options.image))

        # Set up progress bar
        prog_bar = self.xml.get_object("ProgBar")
        prog_bar.set_pulse_step(.05)
        gobject.timeout_add(100, self.prog_bar_pulse)
        prog_bar.show()

        # Fill Message Text
        msg_widget = self.xml.get_object("WaitMessage")
        msg_widget.set_text(message)

        cxguitools.set_default_icon()
        window.show()


    def quit_requested(self, caller):
        # pylint: disable-msg=R0201,W0613
        gtk.main_quit()

    def prog_bar_pulse(self):
        prog_bar = self.xml.get_object("ProgBar")
        prog_bar.pulse()
        return True
